import { Controller, Get, Param, UseGuards } from '@nestjs/common';
import { RoomSessionService } from './roomSession.service';
import { AuthGuard } from '../auth/auth.guard';
import { RoomSessionPointsRequestDto } from './roomSession.dto';

@Controller('sessionPoints')
export class RoomSessionPointsController {
  constructor(
      private readonly roomSession: RoomSessionService) {}

      @UseGuards(AuthGuard)
      @Get('/session/:sessionId')
      /**
       * Retrieves the total points for a specific session based on its session ID.
       *
       * @param sessionId - The unique identifier of the session whose points are being retrieved.
       * @returns A promise that resolves to an object containing the total points and the session ID.
       */
      async getPointsBySession(@Param('sessionId') sessionId: number): Promise<RoomSessionPointsRequestDto> {
        const points = await this.roomSession.getAllPointsBySession(sessionId);
        return points;
      }


}