import { Controller, Get, Param, UseGuards } from '@nestjs/common';
import { RoomSessionUserService } from './roomSessionUser.service';
import { AuthGuard } from '../auth/auth.guard';
import { RoomSessionUserPointsResponseDto } from './roomSessionUser.dto';

@Controller('sessionPoints')
export class RoomSessionUserPointsController {
  constructor(
      private readonly roomSessionUser: RoomSessionUserService) {}

      @UseGuards(AuthGuard)
      @Get('/user/:userId')
      
      /**
       * Retrieves the total points for a specific user based on their user ID.
       *
       * @param userId - The unique identifier of the user whose points are being retrieved.
       * @returns A promise that resolves to an object containing the user's total points and their user ID.
       */
      async getPointsByRoomSessionUser(@Param('userId') userId: number): Promise<RoomSessionUserPointsResponseDto> {
        const points = await this.roomSessionUser.getPointsByRoomSessionUser(userId);
        return { ...points, userId };
      }
}